/*
 *********************************************************************

 $id$


 Copyright (c) 2007-2016 Whitestein Technologies AG,
 Riedstrasse 13, CH-6330 Cham, Switzerland.
 All rights reserved.

 This software is confidential and proprietary information of
 Whitestein Technologies AG.
 You shall not disclose this confidential information and shall use
 it only in accordance with the terms of the license agreement you
 entered into with Whitestein Technologies AG.
 The use of this file in source or binary form requires a written
 license from Whitestein Technologies AG.
 *********************************************************************
 */
package com.whitestein.lsps.pm.ldap;

import java.util.Properties;

/**
 * @author jsa
 *
 */
class LdapSettings {

	private final String host, serviceLogin, servicePassword, base;
	private final String idAttr, loginAttr, securityRoleAttr, firstNameAttr;
	private final String lastNameAttr, phoneAttr, emailAttr, settingsAttr;
	private final String passwordAttr, substitutionActiveAttr, substitutesAttr;
	private final String propertiesAttributes;
	private final String userQueryById;
	private final String userQueryByLogin;
	private final String userGenericQueryCondition;
	private final String userObjectClass;
	private final int port;
	private final boolean readonly;

	LdapSettings(Properties properties) {
		host = properties.getProperty("com.whitestein.ldap.host");
		port = Integer.parseInt(properties.getProperty("com.whitestein.ldap.port"));
		serviceLogin = properties.getProperty("com.whitestein.ldap.servicelogin");
		servicePassword = properties.getProperty("com.whitestein.ldap.servicepassword");
		base = properties.getProperty("com.whitestein.ldap.base");

		//attribute mappings
		idAttr = properties.getProperty("com.whitestein.ldap.idAttribute");
		userObjectClass = properties.getProperty("com.whitestein.ldap.userObjectClass");
		loginAttr = properties.getProperty("com.whitestein.ldap.loginNameAttribute");
		securityRoleAttr = properties.getProperty("com.whitestein.ldap.securityRoleAttribute");

		firstNameAttr = properties.getProperty("com.whitestein.ldap.firstNameAttribute");
		lastNameAttr = properties.getProperty("com.whitestein.ldap.lastNameAttribute");
		emailAttr = properties.getProperty("com.whitestein.ldap.emailAttribute");
		phoneAttr = properties.getProperty("com.whitestein.ldap.phoneAttribute");
		settingsAttr = properties.getProperty("com.whitestein.ldap.settingsAttribute");
		passwordAttr = properties.getProperty("com.whitestein.ldap.passwordAttribute");

		propertiesAttributes = properties.getProperty("com.whitestein.ldap.propertiesAttributes");
		substitutionActiveAttr = properties.getProperty("com.whitestein.ldap.substitutionActive");
		substitutesAttr = properties.getProperty("com.whitestein.ldap.substitutes");

		userQueryById = properties.getProperty("com.whitestein.ldap.userQueryById");
		userQueryByLogin = properties.getProperty("com.whitestein.ldap.userQueryByLogin");
		userGenericQueryCondition = properties.getProperty("com.whitestein.ldap.userGenericQueryCondition");

		String readonlyProp = properties.getProperty("com.whitestein.ldap.readonly");
		readonly = (readonlyProp != null && Boolean.parseBoolean(readonlyProp));
	}

	public String getHost() {
		return host;
	}

	public String getServiceLogin() {
		return serviceLogin;
	}

	public String getServicePassword() {
		return servicePassword;
	}

	public String getBase() {
		return base;
	}

	public String getIdAttr() {
		return idAttr;
	}

	public String getLoginAttr() {
		return loginAttr;
	}

	public String getUserObjectClass() {
		return userObjectClass;
	}

	public String getSecurityRoleAttr() {
		return securityRoleAttr;
	}

	public String getFirstNameAttr() {
		return firstNameAttr;
	}

	public String getLastNameAttr() {
		return lastNameAttr;
	}

	public String getPhoneAttr() {
		return phoneAttr;
	}

	public String getEmailAttr() {
		return emailAttr;
	}

	public String getSettingsAttr() {
		return settingsAttr;
	}

	public String getPasswordAttr() {
		return passwordAttr;
	}

	public String getSubstitutionActiveAttr() {
		return substitutionActiveAttr;
	}

	public String getSubstitutesAttr() {
		return substitutesAttr;
	}

	public String getPropertiesAttributes() {
		return propertiesAttributes;
	}

	public String getUserQueryById() {
		return userQueryById;
	}

	public String getUserQueryByLogin() {
		return userQueryByLogin;
	}

	public String getUserGenericQueryCondition() {
		return userGenericQueryCondition;
	}

	public int getPort() {
		return port;
	}

	public boolean isReadonly() {
		return readonly;
	}

}
