/*
 *********************************************************************

 $Id$


 Copyright (c) 2007-2014 Whitestein Technologies AG,
 Riedstrasse 13, CH-6330 Cham, Switzerland.
 All rights reserved.

 This software is confidential and proprietary information of
 Whitestein Technologies AG.
 You shall not disclose this confidential information and shall use
 it only in accordance with the terms of the license agreement you
 entered into with Whitestein Technologies AG.
 The use of this file in source or binary form requires a written
 license from Whitestein Technologies AG.
 *********************************************************************
 */
package com.whitestein.lsps.pm.ldap;

import java.util.ArrayList;
import java.util.List;

import javax.annotation.security.PermitAll;
import javax.ejb.Stateless;

import com.whitestein.lsps.orgstructure.entity.SecurityRole;
import com.whitestein.lsps.orgstructure.entity.SecurityRoleChange;
import com.whitestein.lsps.orgstructure.entity.SecurityRoleChangePlugin;
import com.whitestein.lsps.orgstructure.entity.SecurityRoleRemovedChange;

/**
 * Implementation of {@link SecurityRoleChangePlugin} interface for LDAP person
 * management.
 *
 * @author jsa
 *
 */
@Stateless
@PermitAll
public class PersonSecurityRoleChangePlugin extends AbstractLdapBean implements SecurityRoleChangePlugin {

	@Override
	public void onChanges(List<SecurityRoleChange> changes) {
		for (SecurityRoleChange change : changes) {
			onChange(change);
		}

	}

	private void onChange(SecurityRoleChange change) {
		if (change instanceof SecurityRoleRemovedChange) {
			SecurityRole securityRole = change.getSecurityRole();

			LdapSession session = createSession();

			StringBuilder query = new StringBuilder("(&");
			query.append(settings.getUserGenericQueryCondition());
			query.append("(");
			query.append(settings.getSecurityRoleAttr());
			query.append("=");
			query.append(securityRole.getName());
			query.append(")");
			query.append(")");

			List<LdapPerson> persons = session.searchPersons(query.toString());

			for (LdapPerson person : persons) {
				List<String> roles = new ArrayList<>(person.getSecurityRoles());
				roles.remove(securityRole.getName());
				person.setSecurityRoleAssignments(roles.toArray(new String[roles.size()]));
			}
		}
	}
}
