/*
 *********************************************************************

 $Id$


 Copyright (c) 2007-2014 Whitestein Technologies AG,
 Riedstrasse 13, CH-6330 Cham, Switzerland.
 All rights reserved.

 This software is confidential and proprietary information of
 Whitestein Technologies AG.
 You shall not disclose this confidential information and shall use
 it only in accordance with the terms of the license agreement you
 entered into with Whitestein Technologies AG.
 The use of this file in source or binary form requires a written
 license from Whitestein Technologies AG.
 *********************************************************************
 */
package com.whitestein.lsps.pm.ldap;

import java.util.List;

import javax.annotation.security.PermitAll;
import javax.ejb.EJB;
import javax.ejb.Stateless;

import com.whitestein.lsps.common.ByteData;
import com.whitestein.lsps.common.RightsAllowed;
import com.whitestein.lsps.os.OsRights;
import com.whitestein.lsps.os.PersonService;
import com.whitestein.lsps.os.dto.Person;
import com.whitestein.lsps.os.dto.PersonCriteria;
import com.whitestein.lsps.os.dto.PersonList;
import com.whitestein.lsps.os.dto.PersonPicture;
import com.whitestein.lsps.os.ejb.PersonManagementServiceLocal;
import com.whitestein.lsps.os.ejb.PersonServiceLocal;
import com.whitestein.lsps.os.ejb.PersonServiceRemote;
import com.whitestein.lsps.os.exception.PersonNotFoundException;
import com.whitestein.lsps.os.exception.PersonPictureException;

/**
 * Implementation of {@link PersonService} for LDAP based user management.
 *
 * @author mbj
 *
 */
@Stateless
@PermitAll
public class PersonServiceBean implements PersonServiceLocal, PersonServiceRemote {

	@EJB(beanName = "PersonManagementServiceBean")
	private PersonManagementServiceLocal connector;

	@Override
	@RightsAllowed(OsRights.READ_PERSON)
	public Person getPerson(String personId) {
		return connector.getPerson(personId);
	}

	@Override
	@RightsAllowed(OsRights.READ_PERSON)
	public Person getPersonByLogin(String login) {
		return connector.getPersonByLogin(login);
	}

	@Override
	public boolean checkActivePersonWithLoginExists(String login) {
		return connector.checkActivePersonWithLoginExists(login);
	}

	@Override
	@RightsAllowed(OsRights.READ_PERSON)
	public PersonList findPersons(PersonCriteria criteria) {
		return connector.findPersons(criteria);
	}

	@Override
	@RightsAllowed(OsRights.READ_PERSON)
	public ByteData getSetting(String personId, String settingName) throws PersonNotFoundException {
		return connector.getSetting(personId, settingName);
	}

	@Override
	@RightsAllowed(OsRights.READ_PERSON)
	public void setSetting(String personId, String settingName, ByteData settingContent) throws PersonNotFoundException {
		connector.setSetting(personId, settingName, settingContent);
	}

	@Override
	@RightsAllowed(OsRights.READ_PERSON)
	public void deleteSetting(String personId, String settingName) throws PersonNotFoundException {
		connector.deleteSetting(personId, settingName);
	}

	@Override
	@RightsAllowed(OsRights.READ_PERSON)
	public boolean hasPersonAnyRight(String loginName, List<String> rights) {
		return connector.hasPersonAnyRight(loginName, rights);
	}

	@Override
	@RightsAllowed(OsRights.READ_PERSON)
	public PersonPicture getPersonPicture(String personId) throws PersonNotFoundException, PersonPictureException {
		return connector.getPersonPicture(personId);
	}

	@Override
	@RightsAllowed(OsRights.READ_PERSON)
	public void setPersonPicture(String personId, PersonPicture picture) throws PersonNotFoundException, PersonPictureException {
		connector.setPersonPicture(personId, picture);
	}

}
